# Brainstorming Meeting Template

Use this template for creative ideation and brainstorming sessions.

```markdown
# [Topic] Brainstorming - [Date]

## Meeting Details
**Date**: [Date]
**Facilitator**: [Name]
**Note-taker**: [Name]
**Attendees**: [List]

## Objective

[Clear statement of what we're brainstorming]

**Success looks like**: [How we'll know brainstorming was successful]

## Background & Context

[Context from research - 2-3 paragraphs]

**Related Pages**:
- <mention-page url="...">Context Page 1</mention-page>
- <mention-page url="...">Context Page 2</mention-page>

## Constraints

- [Constraint]
- [Constraint]
- [Constraint]

## Seed Ideas

[Starting ideas from research to spark discussion]:

1. **[Idea]**: [Brief description]
2. **[Idea]**: [Brief description]

## Ground Rules

- No criticism during ideation
- Build on others' ideas
- Quantity over quality initially
- Wild ideas welcome

## Brainstorming Notes

### Ideas Generated

[To be filled during meeting]

1. [Idea with brief description]
2. [Idea with brief description]

### Themes/Patterns

[Groupings that emerge]

## Evaluation

[If time permits, evaluate top ideas]

### Top Ideas

| Idea | Feasibility | Impact | Effort | Score |
|------|-------------|---------|--------|-------|
| [Idea] | [H/M/L] | [H/M/L] | [H/M/L] | [#] |

## Next Steps

- [ ] [Action to explore idea]
- [ ] [Action to prototype]
- [ ] [Action to research]

## Follow-up

**Next meeting**: [Date to reconvene]
```

